==> bear_1.0.0.tar.gz: bear/R/demoGLM.r <==
#Demo for GLM
options(warn=-1)
demoGLM<-function()
{
TotalData<-data.frame (subj=as.factor(c(1,2,3,4,5,6,7,8,9,10,11,12,13,14,
                                      1,2,3,4,5,6,7,8,9,10,11,12,13,14)),
                       drug=as.factor(c(1,1,1,1,1,1,1,1,1,1,1,1,1,1,
                                      2,2,2,2,2,2,2,2,2,2,2,2,2,2)),
                       seq=as.factor (c(2,1,2,1,2,1,2,1,2,1,2,1,2,1,
                                      2,1,2,1,2,1,2,1,2,1,2,1,2,1)),
                       prd=as.factor (c(2,1,2,1,2,1,2,1,2,1,2,1,2,1,
                                      1,2,1,2,1,2,1,2,1,2,1,2,1,2)),
                       Cmax=c(1739,1481,1780,1374,1555,1756,1566,1939,1475,1388,1127,1542,1235,1598,
                              1633,1837,2073,1629,1385,1522,1643,1615,1759,1483,1682,1247,1605,1718),
                       AUC0t=c(14445,12516,15371,11063,13971,15376,13442,13442,12410,13310,9353,15015,9723,14977,
                               12294,15299,15184,13982,11852,13838,12361,14347,15804,11711,15371,10609,15428,17803),
                       AUC0INF=c(14933,13185,16032,11668,14557,15964,14068,14001,12915,13985,9750,15757,10375,15916,
                                 12972,16209,15691,14650,12550,14343,12979,14681,16565,12544,16029,11093,16308,18870),
                       LnCmax=c(7.46,7.30,7.48,7.23,7.35,7.47,7.36,7.57,7.30,7.24,7.03,7.34,7.12,7.38,
                                7.40,7.52,7.64,7.40,7.23,7.33,7.40,7.39,7.47,7.30,7.43,7.13,7.38,7.45),
                       LnAUC0t=c(9.58,9.43,9.64,9.31,9.54,9.64,9.51,9.50,9.43,9.50,9.14,9.62,9.18,9.61,
                                 9.42,9.64,9.63,9.55,9.38,9.54,9.42,9.57,9.67,9.37,9.64,9.27,9.64,9.79),
                     LnAUC0INF=c(9.61,9.49,9.68,9.36,9.59,9.68,9.55,9.55,9.47,9.55,9.19,9.67,9.25,9.68,
                                 9.47,9.69,9.66,9.59,9.44,9.57,9.47,9.59,9.72,9.44,9.68,9.31,9.70,9.85))

#Generalized Linear Models (GLM)
cat("****************************************************************************\n")
cat("*                      Generalized Linear Models (GLM)                     *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("* A two-treatment, two-period, two-sequence (2x2) randomized crossover     *\n")
cat("* design, the statistical model includes factors accounting for the        *\n")
cat("* following sources of variation: sequence, subjects nested in sequences,  *\n")
cat("* period and treatment.  GLM was used to obtain estimates for the adjusted *\n")
cat("* differences between treatment means and the standard error associated    *\n")
cat("* with these differences.  Log-transformed BA measures were also analyzed. *\n")
cat("****************************************************************************\n")

Fdata<-split(TotalData, list(TotalData$drug))
RefData<-Fdata[[1]]
TestData<-Fdata[[2]]

#represent GLM
cat("****************************************************************************\n")
cat("*                   General Linear Model Procedure                         *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: Cmax                                                  \n")
cat("\n")
Cmax<- lm(Cmax ~ seq + subj + prd + drug , data=TotalData)
summary(Cmax)
show(anova(Cmax))
cat("\n")
cat(" Tests of Hypothese using the Type I MS for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
Cmax1<- lm(Cmax ~ seq , data=TotalData)
show(anova(Cmax1))
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                   General Linear Model Procedure                         *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: AUC0t                                                \n")
cat("\n")
AUC0t<- lm(AUC0t ~ seq + subj+ prd + drug , data=TotalData)
summary(AUC0t)
show(anova(AUC0t))
cat("\n")
cat(" Tests of Hypothese using the Type I MS for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
AUC0t1<- lm(AUC0t ~ seq , data=TotalData)
show(anova(AUC0t1))
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                   General Linear Model Procedure                         *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: AUC0inf                                               \n")
cat("\n")
AUC0INF<- lm(AUC0INF ~ seq + subj+ prd + drug , data=TotalData)
summary(AUC0INF)
show(anova(AUC0INF))
cat("\n")
cat(" Tests of Hypothese using the Type I MS for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
AUC0INF1<- lm(AUC0INF ~ seq , data=TotalData)
show(anova(AUC0INF1))
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                   General Linear Model Procedure                         *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnCmax                                               \n")
cat("\n")
LnCmax<- lm(LnCmax ~ seq + subj + prd + drug , data=TotalData)
summary(LnCmax)
show(anova(LnCmax))
cat("\n")
cat(" Tests of Hypothese using the Type I MS for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
LnCmax1<- lm(LnCmax ~ seq , data=TotalData)
show(anova(LnCmax1))
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                   General Linear Model Procedure                         *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnAUC0t                                               \n")
cat("\n")
LnAUC0t<- lm(LnAUC0t ~ seq + subj + prd + drug , data=TotalData)
summary(LnAUC0t)
show(anova(LnAUC0t))
cat("\n")
cat(" Tests of Hypothese using the Type I MS for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
LnAUC0t1<- lm(LnAUC0t ~ seq , data=TotalData)
show(anova(LnAUC0t1))
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                   General Linear Model Procedure                         *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnAUC0inf                                             \n")
cat("\n")
LnAUC0INF<- lm(LnAUC0INF ~ seq + subj + prd + drug , data=TotalData)
summary(LnAUC0INF)
show(anova(LnAUC0INF))
cat("\n")
cat(" Tests of Hypothese using the Type I MS for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
LnAUC0INF1<- lm(LnAUC0INF ~ seq , data=TotalData)
show(anova(LnAUC0INF1))
cat("****************************************************************************\n")
########REPORT
#L1(Reference-->Test),L2(Test-->Reference sequence)
SeqLeg<-split(RefData, list(RefData$seq))
L1<-length(SeqLeg[[1]]$seq)
L2<-length(SeqLeg[[2]]$seq)
T<-qt(0.95,(L1+L2-2))

ref_Cmax<-mean(RefData$LnCmax)
ref_AUC0t<-mean(RefData$LnAUC0t)
ref_AUC0INF<-mean(RefData$LnAUC0INF)

test_Cmax<-mean(TestData$LnCmax)
test_AUC0t<-mean(TestData$LnAUC0t)
test_AUC0INF<-mean(TestData$LnAUC0INF)

SE_Cmax<-sqrt((anova(LnCmax)[5,3]/2) * (1/L1+1/L2))
SE_AUC0t<-sqrt((anova(LnAUC0t)[5,3]/2) * (1/L1+1/L2))
SE_AUC0INF<-sqrt((anova(LnAUC0INF)[5,3]/2) * (1/L1+1/L2))
Z_Cmax<-0.2*(ref_Cmax/SE_Cmax)-qnorm(0.95)
Z_AUC0t<-0.2*(ref_AUC0t/SE_AUC0t)-qnorm(0.95)
Z_AUC0INF<-0.2*(ref_AUC0INF/SE_AUC0INF)-qnorm(0.95)

T_Cmax<-0.2*(ref_Cmax/SE_Cmax)-qt(0.975,L1+L2-2)
T_AUC0t<-0.2*(ref_AUC0t/SE_AUC0t)-qt(0.975,L1+L2-2)
T_AUC0INF<-0.2*(ref_AUC0INF/SE_AUC0INF)-qt(0.975,L1+L2-2)

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                        Cross-over Design Report                          *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnCmax                                               \n")
cat("*--------------------------------------------------------------------------*\n")
cat("n1(R=>T)=", L1 , "\n")
cat("n2(T=>R)=", L2 , "\n")
cat("N(n1+n2)=", L1+L2 , "\n")
cat("LSM-ref=", ref_Cmax, "\n")
cat("LSM-test=",test_Cmax, "\n")
cat("MSE=",anova(LnCmax)[5,3], "\n")
cat("SE=",SE_Cmax, "\n")
cat("Diff. (test-ref)=", test_Cmax-ref_Cmax, "\n")
cat("t(0.95,N-2)=",T , "\n")
cat("Z(beta)=",Z_Cmax, "\n")
cat("Power(1-beta)_Z=", pnorm(abs(Z_Cmax)),"\n")
cat("t(beta)=",T_Cmax, "\n")
cat("Power(1-beta)_t=", pt(T_Cmax,L1+L2-2) ,"\n")
cat("\n")
lowerCmax<-100*exp((test_Cmax-ref_Cmax)-(T*SE_Cmax))
upperCmax<-100*exp((test_Cmax-ref_Cmax)+(T*SE_Cmax))
cat("************************90% C.I. for Ln (Cmax)****************************\n")
cat("90% CI Lower=", round(lowerCmax,3) ,"\n")
cat("90% CI Upper=", round(upperCmax,3) ,"\n")
if  (lowerCmax>80 && upperCmax<125)
 {
  cat("\n")
  cat("Bioequivalence= Pass!!!\n")
  }
  else{
   cat("\n")
   cat("Bioequivalence= Fail!!!\n")
  }
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                         Cross-over Design Report                         *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnAUC0t                                               \n")
cat("*--------------------------------------------------------------------------*\n")
cat("n1(R=>T)=", L1 , "\n")
cat("n2(T=>R)=", L2 , "\n")
cat("N(n1+n2)=", L1+L2 , "\n")
cat("LSM-ref=", ref_AUC0t, "\n")
cat("LSM-test=",test_AUC0t, "\n")
cat("MSE=",anova(LnAUC0t)[5,3], "\n")
cat("SE=",SE_AUC0t, "\n")
cat("Diff. (test-ref)=", test_AUC0t-ref_AUC0t, "\n")
cat("t(0.95,N-2)=",T , "\n")
cat("Z(beta)=",Z_AUC0t, "\n")
cat("Power(1-beta)_Z=", pnorm(abs(Z_AUC0t)),"\n")
cat("t(beta)=",T_AUC0t, "\n")
cat("Power(1-beta)_t=",pt(T_AUC0t,L1+L2-2),"\n")
cat("\n")
lowerAUC0t<-100*exp((test_AUC0t-ref_AUC0t)-(T*SE_AUC0t))
UpperAUC0t<-100*exp((test_AUC0t-ref_AUC0t)+(T*SE_AUC0t))
cat("************************90% C.I. for Ln (AUC0t)****************************\n")
cat("90% CI Lower=", round(lowerAUC0t,3) ,"\n")
cat("90% CI Upper=", round(UpperAUC0t,3) ,"\n")
if  (lowerAUC0t>80 && UpperAUC0t<125)
 {
  cat("\n")
  cat("Bioequivalence= Pass!!!\n")
  }
  else{
   cat("\n")
   cat("Bioequivalence= Fail!!!\n")
  }
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                           Cross-over Design Report                       *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: AUC0inf                                               \n")
cat("*--------------------------------------------------------------------------*\n")
cat("n1(R=>T)=", L1 , "\n")
cat("n2(T=>R)=", L2 , "\n")
cat("N(n1+n2)=", L1+L2 , "\n")
cat("LSM-ref=", ref_AUC0INF, "\n")
cat("LSM-test=",test_AUC0INF, "\n")
cat("MSE=",anova(LnAUC0INF)[5,3], "\n")
cat("SE=",SE_AUC0INF, "\n")
cat("Diff. (test-ref)=", test_AUC0INF - ref_AUC0INF, "\n")
cat("t(0.95,N-2)=",T , "\n")
cat("Z(beta)=",Z_AUC0INF, "\n")
cat("Power(1-beta)_Z=",pnorm(abs(Z_AUC0INF)),"\n")
cat("t(beta)=",T_AUC0INF, "\n")
cat("Power(1-beta)_t=",pt(T_AUC0INF,L1+L2-2),"\n")
cat("\n")
LowerAUC0INF<-100*exp((test_AUC0INF - ref_AUC0INF)-(T*SE_AUC0INF))
UpperAUC0INF<-100*exp((test_AUC0INF - ref_AUC0INF)+(T*SE_AUC0INF))
cat("************************90% C.I. for Ln (AUC0inf)***************************\n")
cat("90% CI Lower=", round(LowerAUC0INF,3) ,"\n")
cat("90% CI Upper=", round(UpperAUC0INF,3) ,"\n")
if  (LowerAUC0INF>80 && UpperAUC0INF<125)
 {
  cat("\n")
  cat("Bioequivalence= Pass!!!\n")
  }
  else{
   cat("\n")
   cat("Bioequivalence= Fail!!!\n")
  }
cat("****************************************************************************\n")
GLMmenu()
}

==> bear_1.1.3.tar.gz: bear/R/demoGLM.r <==
#Demo for GLM
options(warn=-1)
demoGLM<-function()
{
TotalData<-data.frame (subj=as.factor(c(1,2,3,4,5,6,7,8,9,10,11,12,13,14,
                                      1,2,3,4,5,6,7,8,9,10,11,12,13,14)),
                       drug=as.factor(c(1,1,1,1,1,1,1,1,1,1,1,1,1,1,
                                      2,2,2,2,2,2,2,2,2,2,2,2,2,2)),
                       seq=as.factor (c(2,1,2,1,2,1,2,1,2,1,2,1,2,1,
                                      2,1,2,1,2,1,2,1,2,1,2,1,2,1)),
                       prd=as.factor (c(2,1,2,1,2,1,2,1,2,1,2,1,2,1,
                                      1,2,1,2,1,2,1,2,1,2,1,2,1,2)),
                       Cmax=c(1739,1481,1780,1374,1555,1756,1566,1939,1475,1388,1127,1542,1235,1598,
                              1633,1837,2073,1629,1385,1522,1643,1615,1759,1483,1682,1247,1605,1718),
                       AUC0t=c(14445,12516,15371,11063,13971,15376,13442,13442,12410,13310,9353,15015,9723,14977,
                               12294,15299,15184,13982,11852,13838,12361,14347,15804,11711,15371,10609,15428,17803),
                       AUC0INF=c(14933,13185,16032,11668,14557,15964,14068,14001,12915,13985,9750,15757,10375,15916,
                                 12972,16209,15691,14650,12550,14343,12979,14681,16565,12544,16029,11093,16308,18870),
                       LnCmax=c(7.46,7.30,7.48,7.23,7.35,7.47,7.36,7.57,7.30,7.24,7.03,7.34,7.12,7.38,
                                7.40,7.52,7.64,7.40,7.23,7.33,7.40,7.39,7.47,7.30,7.43,7.13,7.38,7.45),
                       LnAUC0t=c(9.58,9.43,9.64,9.31,9.54,9.64,9.51,9.50,9.43,9.50,9.14,9.62,9.18,9.61,
                                 9.42,9.64,9.63,9.55,9.38,9.54,9.42,9.57,9.67,9.37,9.64,9.27,9.64,9.79),
                     LnAUC0INF=c(9.61,9.49,9.68,9.36,9.59,9.68,9.55,9.55,9.47,9.55,9.19,9.67,9.25,9.68,
                                 9.47,9.69,9.66,9.59,9.44,9.57,9.47,9.59,9.72,9.44,9.68,9.31,9.70,9.85))

#Generalized Linear Models (GLM)
cat("****************************************************************************\n")
cat("*                                  ANOVA (lm)                              *\n")
cat("*--------------------------------------------------------------------------*\n")
cat("* With a two-treatment, two-period, two-sequence randomized crossover      *\n")
cat("* design, ANOVA statistical model includes factors of the following sources*\n")
cat("* :sequence, subjects nested in sequences, period and treatment. ANOVA will*\n")
cat("* be applied to obtain estimates for the adjusted differences between      *\n")
cat("* treatment means and the standard error associated with these differences.*\n")
cat("* Log-transformed BA measures will also be analyzed.                       *\n")
cat("****************************************************************************\n")

Fdata<-split(TotalData, list(TotalData$drug))
RefData<-Fdata[[1]]
TestData<-Fdata[[2]]

#represent GLM
cat("****************************************************************************\n")
cat("*                           ANOVA (lm) Procedure                           *\n") 
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: Cmax                                                  \n")
cat("\n")
Cmax<- lm(Cmax ~ seq + subj + prd + drug , data=TotalData)
summary(Cmax)
show(anova(Cmax))
cat("\n")
cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
Cmax1<- lm(Cmax ~ seq , data=TotalData)
show(anova(Cmax1))
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                           ANOVA (lm) Procedure                           *\n") 
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: AUC0t                                                \n")
cat("\n")
AUC0t<- lm(AUC0t ~ seq + subj+ prd + drug , data=TotalData)
summary(AUC0t)
show(anova(AUC0t))
cat("\n")
cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
AUC0t1<- lm(AUC0t ~ seq , data=TotalData)
show(anova(AUC0t1))
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                           ANOVA (lm) Procedure                           *\n") 
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: AUC0inf                                               \n")
cat("\n")
AUC0INF<- lm(AUC0INF ~ seq + subj+ prd + drug , data=TotalData)
summary(AUC0INF)
show(anova(AUC0INF))
cat("\n")
cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
AUC0INF1<- lm(AUC0INF ~ seq , data=TotalData)
show(anova(AUC0INF1))
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                           ANOVA (lm) Procedure                           *\n") 
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnCmax                                               \n")
cat("\n")
LnCmax<- lm(LnCmax ~ seq + subj + prd + drug , data=TotalData)
summary(LnCmax)
show(anova(LnCmax))
cat("\n")
cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
LnCmax1<- lm(LnCmax ~ seq , data=TotalData)
show(anova(LnCmax1))
cat("\n")
cat("Intra_subject CV=100*sqrt(MSResidual)=",100*sqrt(anova(LnCmax)[5,3]),"%\n")
cat("Inter_subject CV=100*sqrt((MSSubject(seq)-MSResidual)/2)=",100*sqrt(abs(anova(LnCmax)[2,3]-anova(LnCmax)[5,3])/2),"%\n")
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                           ANOVA (lm) Procedure                           *\n") 
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnAUC0t                                               \n")
cat("\n")
LnAUC0t<- lm(LnAUC0t ~ seq + subj + prd + drug , data=TotalData)
summary(LnAUC0t)
show(anova(LnAUC0t))
cat("\n")
cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
LnAUC0t1<- lm(LnAUC0t ~ seq , data=TotalData)
show(anova(LnAUC0t1))
cat("\n")
cat("Intra_subject CV=100*sqrt(MSResidual)=",100*sqrt(anova(LnAUC0t)[5,3]),"%\n")
cat("Inter_subject CV=100*sqrt((MSSubject(seq)-MSResidual)/2)=",100*sqrt(abs(anova(LnAUC0t)[2,3]-anova(LnAUC0t)[5,3])/2),"%\n")
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                           ANOVA (lm) Procedure                           *\n") 
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnAUC0inf                                             \n")
cat("\n")
LnAUC0INF<- lm(LnAUC0INF ~ seq + subj + prd + drug , data=TotalData)
summary(LnAUC0INF)
show(anova(LnAUC0INF))
cat("\n")
cat(" Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
cat("\n")
LnAUC0INF1<- lm(LnAUC0INF ~ seq , data=TotalData)
show(anova(LnAUC0INF1))
cat("\n")
cat("Intra_subject CV=100*sqrt(MSResidual)=",100*sqrt(anova(LnAUC0INF)[5,3]),"%\n")
cat("Inter_subject CV=100*sqrt((MSSubject(seq)-MSResidual)/2)=",100*sqrt(abs(anova(LnAUC0INF)[2,3]-anova(LnAUC0INF)[5,3])/2),"%\n")
cat("****************************************************************************\n")
########REPORT
#L1(Reference-->Test),L2(Test-->Reference sequence)
SeqLeg<-split(RefData, list(RefData$seq))
L1<-length(SeqLeg[[1]]$seq)
L2<-length(SeqLeg[[2]]$seq)
T<-qt(0.95,(L1+L2-2))

ref_Cmax<-mean(RefData$LnCmax)
ref_AUC0t<-mean(RefData$LnAUC0t)
ref_AUC0INF<-mean(RefData$LnAUC0INF)

test_Cmax<-mean(TestData$LnCmax)
test_AUC0t<-mean(TestData$LnAUC0t)
test_AUC0INF<-mean(TestData$LnAUC0INF)

SE_Cmax<-sqrt((anova(LnCmax)[5,3]/2) * (1/L1+1/L2))
SE_AUC0t<-sqrt((anova(LnAUC0t)[5,3]/2) * (1/L1+1/L2))
SE_AUC0INF<-sqrt((anova(LnAUC0INF)[5,3]/2) * (1/L1+1/L2))
Z_Cmax<-0.2*(ref_Cmax/SE_Cmax)-qnorm(0.95)
Z_AUC0t<-0.2*(ref_AUC0t/SE_AUC0t)-qnorm(0.95)
Z_AUC0INF<-0.2*(ref_AUC0INF/SE_AUC0INF)-qnorm(0.95)

T_Cmax<-0.2*(ref_Cmax/SE_Cmax)-qt(0.975,L1+L2-2)
T_AUC0t<-0.2*(ref_AUC0t/SE_AUC0t)-qt(0.975,L1+L2-2)
T_AUC0INF<-0.2*(ref_AUC0INF/SE_AUC0INF)-qt(0.975,L1+L2-2)

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                            BE Summary Report                             *\n") 
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnCmax                                               \n")
cat("*--------------------------------------------------------------------------*\n")
cat("n1(R=>T)=", L1 , "\n")
cat("n2(T=>R)=", L2 , "\n")
cat("N(n1+n2)=", L1+L2 , "\n")
cat("LSM-ref=", ref_Cmax, "\n")
cat("LSM-test=",test_Cmax, "\n")
cat("MSE=",anova(LnCmax)[5,3], "\n")
cat("SE=",SE_Cmax, "\n")
cat("Diff. (test-ref)=", test_Cmax-ref_Cmax, "\n")
cat("t(0.95,N-2)=",T , "\n")
cat("Z(beta)=",Z_Cmax, "\n")
cat("Power(1-beta)_Z=", pnorm(abs(Z_Cmax)),"\n")
cat("t(beta)=",T_Cmax, "\n")
cat("Power(1-beta)_t=", pt(T_Cmax,L1+L2-2) ,"\n")
cat("\n")
lowerCmax<-100*exp((test_Cmax-ref_Cmax)-(T*SE_Cmax))
upperCmax<-100*exp((test_Cmax-ref_Cmax)+(T*SE_Cmax))
cat("************************90% C.I. for Ln (Cmax)****************************\n")
cat("90% CI Lower=", round(lowerCmax,3) ,"\n")
cat("90% CI Upper=", round(upperCmax,3) ,"\n")
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                            BE Summary Report                             *\n") 
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: LnAUC0t                                               \n")
cat("*--------------------------------------------------------------------------*\n")
cat("n1(R=>T)=", L1 , "\n")
cat("n2(T=>R)=", L2 , "\n")
cat("N(n1+n2)=", L1+L2 , "\n")
cat("LSM-ref=", ref_AUC0t, "\n")
cat("LSM-test=",test_AUC0t, "\n")
cat("MSE=",anova(LnAUC0t)[5,3], "\n")
cat("SE=",SE_AUC0t, "\n")
cat("Diff. (test-ref)=", test_AUC0t-ref_AUC0t, "\n")
cat("t(0.95,N-2)=",T , "\n")
cat("Z(beta)=",Z_AUC0t, "\n")
cat("Power(1-beta)_Z=", pnorm(abs(Z_AUC0t)),"\n")
cat("t(beta)=",T_AUC0t, "\n")
cat("Power(1-beta)_t=",pt(T_AUC0t,L1+L2-2),"\n")
cat("\n")
lowerAUC0t<-100*exp((test_AUC0t-ref_AUC0t)-(T*SE_AUC0t))
UpperAUC0t<-100*exp((test_AUC0t-ref_AUC0t)+(T*SE_AUC0t))
cat("************************90% C.I. for Ln (AUC0t)****************************\n")
cat("90% CI Lower=", round(lowerAUC0t,3) ,"\n")
cat("90% CI Upper=", round(UpperAUC0t,3) ,"\n")
cat("****************************************************************************\n")

cat("\n")
cat("\n")
cat("****************************************************************************\n")
cat("*                            BE Summary Report                             *\n") 
cat("*--------------------------------------------------------------------------*\n")
cat("  Dependent Variable: AUC0inf                                               \n")
cat("*--------------------------------------------------------------------------*\n")
cat("n1(R=>T)=", L1 , "\n")
cat("n2(T=>R)=", L2 , "\n")
cat("N(n1+n2)=", L1+L2 , "\n")
cat("LSM-ref=", ref_AUC0INF, "\n")
cat("LSM-test=",test_AUC0INF, "\n")
cat("MSE=",anova(LnAUC0INF)[5,3], "\n")
cat("SE=",SE_AUC0INF, "\n")
cat("Diff. (test-ref)=", test_AUC0INF - ref_AUC0INF, "\n")
cat("t(0.95,N-2)=",T , "\n")
cat("Z(beta)=",Z_AUC0INF, "\n")
cat("Power(1-beta)_Z=",pnorm(abs(Z_AUC0INF)),"\n")
cat("t(beta)=",T_AUC0INF, "\n")
cat("Power(1-beta)_t=",pt(T_AUC0INF,L1+L2-2),"\n")
cat("\n")
LowerAUC0INF<-100*exp((test_AUC0INF - ref_AUC0INF)-(T*SE_AUC0INF))
UpperAUC0INF<-100*exp((test_AUC0INF - ref_AUC0INF)+(T*SE_AUC0INF))
cat("************************90% C.I. for Ln (AUC0inf)***************************\n")
cat("90% CI Lower=", round(LowerAUC0INF,3) ,"\n")
cat("90% CI Upper=", round(UpperAUC0INF,3) ,"\n")
cat("****************************************************************************\n")
GLMmenu()
}
